RangeQueryTs

Enum RangeQueryTs 

pub enum RangeQueryTs {
    Exact(Timestamp),
    Bounds(RangeBoundsTs),
}
A set of generic request parameters that can be used on list endpoints to filter their results by some timestamp.

Variants



Exact(Timestamp)

Results matching a specific UNIX timestamp



Bounds(RangeBoundsTs)

Results falling with a date interval

Implementations

Source

impl RangeQueryTs

pub fn eq(value: Timestamp) -> Self

Filter results to exactly match a given value

pub fn gt(value: Timestamp) -> Self

Filter results to be after a given value

pub fn gte(value: Timestamp) -> Self

Filter results to be after or equal to a given value

pub fn lt(value: Timestamp) -> Self

Filter results to be before to a given value

pub fn lte(value: Timestamp) -> Self

Filter results to be before or equal to a given value